@@ -1,4 +1,3 @@
-from ia.gaius.data_language import CLEAR_WM, LEARN
 from ia.gaius.prediction_models import make_modeled_emotives, hive_model_emotives
 
 
@@ -14,7 +13,9 @@ class Tester:
         return
 
     def train(self, sequence):
-        record = {'phase': 'training', 'historical_expecting': sum([sum(data['emotives'].values()) for data in sequence])}
+        record = {'phase': 'training',
+                  'historical_expecting': sum([sum(data['emotives'].values())
+                                               for data in sequence])}
         self.bottle.clear_wm()
         for data in sequence:
             self.bottle.observe(data)
@@ -37,7 +38,8 @@ class Tester:
         for answer in answers:
             for node, ensemble in answer.items():
                 predicted_value = make_modeled_emotives(ensemble)
-                hive_prediction.append(predicted_value)  # Add to hive model's list for later
+                # Add to hive model's list for later
+                hive_prediction.append(predicted_value)
                 record['node_predictions'][node] = predicted_value
 
         hive_prediction = hive_model_emotives(hive_prediction)
@@ -47,9 +49,12 @@ class Tester:
 
         if self.learning_strategy == 'continuous' or (
                 self.learning_strategy == 'on-error' and predicton_error):
-            # NOTE!: Unlike regular symbols for the classification tests, utilities pass through
-            # all nodes, so we don't need to send directly to egress nodes.  Simply send through ingress nodes.
-            data = {"strings": [], "vectors": [], "emotives": {'utility': historical_expecting}}
+            # NOTE!: Unlike regular symbols for the classification tests,
+            # utilities pass through all nodes, so we don't need to send
+            # directly to egress nodes. Simply send through ingress nodes.
+            data = {"strings": [],
+                    "vectors": [],
+                    "emotives": {'utility': historical_expecting}}
             self.bottle.observe(data)
             self.bottle.learn()
         return record
